Title: [98271] trunk/Source
- Revision
- 98271
- Author
- [email protected]
- Date
- 2011-10-24 13:11:56 -0700 (Mon, 24 Oct 2011)
Log Message
[chromium] Expose WebThread::postDelayedTask to CCThread
https://bugs.webkit.org/show_bug.cgi?id=70712
Reviewed by James Robinson.
Source/WebCore:
* platform/graphics/chromium/cc/CCThread.h:
Source/WebKit/chromium:
* src/CCThreadImpl.cpp:
(WebKit::CCThreadImpl::postDelayedTask):
* src/CCThreadImpl.h:
Modified Paths
Diff
Modified: trunk/Source/WebCore/ChangeLog (98270 => 98271)
--- trunk/Source/WebCore/ChangeLog 2011-10-24 19:55:26 UTC (rev 98270)
+++ trunk/Source/WebCore/ChangeLog 2011-10-24 20:11:56 UTC (rev 98271)
@@ -1,3 +1,12 @@
+2011-10-24 Nat Duca <[email protected]>
+
+ [chromium] Expose WebThread::postDelayedTask to CCThread
+ https://bugs.webkit.org/show_bug.cgi?id=70712
+
+ Reviewed by James Robinson.
+
+ * platform/graphics/chromium/cc/CCThread.h:
+
2011-10-24 Levi Weintraub <[email protected]>
<svg> fails to use explicit width and height inside <html> inside IFRAME
Modified: trunk/Source/WebCore/platform/graphics/chromium/cc/CCThread.h (98270 => 98271)
--- trunk/Source/WebKit/chromium/ChangeLog 2011-10-24 19:55:26 UTC (rev 98270)
+++ trunk/Source/WebKit/chromium/ChangeLog 2011-10-24 20:11:56 UTC (rev 98271)
@@ -1,5 +1,16 @@
2011-10-24 Nat Duca <[email protected]>
+ [chromium] Expose WebThread::postDelayedTask to CCThread
+ https://bugs.webkit.org/show_bug.cgi?id=70712
+
+ Reviewed by James Robinson.
+
+ * src/CCThreadImpl.cpp:
+ (WebKit::CCThreadImpl::postDelayedTask):
+ * src/CCThreadImpl.h:
+
+2011-10-24 Nat Duca <[email protected]>
+
[chromium] Manage webkit_unit_tests TestSuite lifetime explicitly in DLL build
https://bugs.webkit.org/show_bug.cgi?id=70688
Modified: trunk/Source/WebKit/chromium/src/CCThreadImpl.cpp (98270 => 98271)
--- trunk/Source/WebKit/chromium/src/CCThreadImpl.cpp 2011-10-24 19:55:26 UTC (rev 98270)
+++ trunk/Source/WebKit/chromium/src/CCThreadImpl.cpp 2011-10-24 20:11:56 UTC (rev 98271)
@@ -90,6 +90,11 @@
m_thread->postTask(new CCThreadTaskAdapter(task));
}
+void CCThreadImpl::postDelayedTask(PassOwnPtr<CCThread::Task> task, long long delayMs)
+{
+ m_thread->postDelayedTask(new CCThreadTaskAdapter(task), delayMs);
+}
+
ThreadIdentifier CCThreadImpl::threadID() const
{
return m_threadID;
Modified: trunk/Source/WebKit/chromium/src/CCThreadImpl.h (98270 => 98271)
--- trunk/Source/WebKit/chromium/src/CCThreadImpl.h 2011-10-24 19:55:26 UTC (rev 98270)
+++ trunk/Source/WebKit/chromium/src/CCThreadImpl.h 2011-10-24 20:11:56 UTC (rev 98271)
@@ -39,7 +39,8 @@
public:
static PassOwnPtr<WebCore::CCThread> create(WebThread*);
virtual ~CCThreadImpl();
- void postTask(PassOwnPtr<WebCore::CCThread::Task>);
+ virtual void postTask(PassOwnPtr<WebCore::CCThread::Task>);
+ virtual void postDelayedTask(PassOwnPtr<WebCore::CCThread::Task>, long long delayMs);
WTF::ThreadIdentifier threadID() const;
private:
_______________________________________________
webkit-changes mailing list
[email protected]
http://lists.webkit.org/mailman/listinfo.cgi/webkit-changes
--- trunk/Source/WebCore/platform/graphics/chromium/cc/CCThread.h 2011-10-24 19:55:26 UTC (rev 98270)
+++ trunk/Source/WebCore/platform/graphics/chromium/cc/CCThread.h 2011-10-24 20:11:56 UTC (rev 98271)
@@ -47,8 +47,12 @@
void* m_instance;
};
- virtual void postTask(PassOwnPtr<Task>) = 0; // Executes the task on context's thread asynchronously.
+ // Executes the task on context's thread asynchronously.
+ virtual void postTask(PassOwnPtr<Task>) = 0;
+ // Executes the task after the specified delay.
+ virtual void postDelayedTask(PassOwnPtr<Task>, long long delayMs) = 0;
+
virtual WTF::ThreadIdentifier threadID() const = 0;
};
Modified: trunk/Source/WebKit/chromium/ChangeLog (98270 => 98271)